summaryrefslogtreecommitdiff
path: root/nuttx
diff options
context:
space:
mode:
authorGregory Nutt <gnutt@nuttx.org>2015-01-17 10:27:57 -0600
committerGregory Nutt <gnutt@nuttx.org>2015-01-17 10:27:57 -0600
commit0847f74ab27f3cb3c9affefd3cf823b0f4a95a52 (patch)
tree194797b950d7b0bdf3f8dd188a2e4546e406cf23 /nuttx
parent4350a9ef77a3e0c6170d74e68722943978717d5b (diff)
downloadpx4-nuttx-0847f74ab27f3cb3c9affefd3cf823b0f4a95a52.tar.gz
px4-nuttx-0847f74ab27f3cb3c9affefd3cf823b0f4a95a52.tar.bz2
px4-nuttx-0847f74ab27f3cb3c9affefd3cf823b0f4a95a52.zip
Tiva Ethernet: Costmetic changes to comments and debug strings
Diffstat (limited to 'nuttx')
-rw-r--r--nuttx/arch/arm/src/tiva/tm4c_ethernet.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/nuttx/arch/arm/src/tiva/tm4c_ethernet.c b/nuttx/arch/arm/src/tiva/tm4c_ethernet.c
index a0928b326..8ef82c0e1 100644
--- a/nuttx/arch/arm/src/tiva/tm4c_ethernet.c
+++ b/nuttx/arch/arm/src/tiva/tm4c_ethernet.c
@@ -1857,7 +1857,7 @@ static void tiva_freeframe(FAR struct tiva_ethmac_s *priv)
txdesc->tdes2 = 0;
- /* Check if this is the last segement of a TX frame */
+ /* Check if this is the last segment of a TX frame */
if ((txdesc->tdes0 & EMAC_TDES0_LS) != 0)
{
@@ -1918,7 +1918,7 @@ static void tiva_txdone(FAR struct tiva_ethmac_s *priv)
{
DEBUGASSERT(priv->txtail != NULL);
- /* Scan the TX desciptor change, returning buffers to free list */
+ /* Scan the TX descriptor change, returning buffers to free list */
tiva_freeframe(priv);
@@ -2014,13 +2014,13 @@ static inline void tiva_interrupt_process(FAR struct tiva_ethmac_s *priv)
#ifdef CONFIG_DEBUG_NET
/* Check if there are pending "anormal" interrupts */
if ((dmaris & EMAC_DMAINT_AIS) != 0)
{
/* Just let the user know what happened */
- nlldbg("Abormal event(s): %08x\n", dmaris);
+ nlldbg("Abnormal event(s): %08x\n", dmaris);
/* Clear all pending abnormal events */
@@ -2201,7 +2201,7 @@ static inline void tiva_txtimeout_process(FAR struct tiva_ethmac_s *priv)
#ifdef CONFIG_NET_NOINTS
static void tiva_txtimeout_work(FAR void *arg)
{
- FAR struct tiva_ethmac_s *priv = ( FAR struct tiva_ethmac_s *)arg;
+ FAR struct tiva_ethmac_s *priv = (FAR struct tiva_ethmac_s *)arg;
/* Process pending Ethernet interrupts */
@@ -2621,7 +2621,7 @@ static int tiva_addmac(struct net_driver_s *dev, FAR const uint8_t *mac)
/* Add the MAC address to the hardware multicast hash table */
- crc = tiva_calcethcrc( mac, 6 );
+ crc = tiva_calcethcrc(mac, 6);
hashindex = (crc >> 26) & 0x3F;
@@ -2678,7 +2678,7 @@ static int tiva_rmmac(struct net_driver_s *dev, FAR const uint8_t *mac)
/* Remove the MAC address to the hardware multicast hash table */
- crc = tiva_calcethcrc( mac, 6 );
+ crc = tiva_calcethcrc(mac, 6);
hashindex = (crc >> 26) & 0x3F;
@@ -2698,7 +2698,7 @@ static int tiva_rmmac(struct net_driver_s *dev, FAR const uint8_t *mac)
/* If there is no address registered any more, delete multicast filtering */
- if (tiva_getreg(TIVA_EMAC_HASHTBLH ) == 0 &&
+ if (tiva_getreg(TIVA_EMAC_HASHTBLH) == 0 &&
tiva_getreg(TIVA_EMAC_HASHTBLL) == 0)
{
temp = tiva_getreg(TIVA_EMAC_FRAMEFLTR);
@@ -2014,13 +2014,13 @@ static inline void tiva_interrupt_process(FAR struct tiva_ethmac_s *priv)
#ifdef CONFIG_DEBUG_NET
- /* Check if there are pending "anormal" interrupts */
+ /* Check if there are pending "abnormal" interrupts */
if ((dmaris & EMAC_DMAINT_AIS) != 0)
{